@@ -245,7 +245,7 @@ class Bailador::App does Bailador::Routing {
         self!sessions.store(self.response, self.request.env);
     }
 
-    method log-request(DateTime $start, DateTime $end, Str $method, Str $uri, Int $http-code) {
+    method log-request(DateTime $start, DateTime $end, Str() $method, Str() $uri, Int $http-code) {
         my $env = self.context.env;
         my $severity = 'error';
         given $http-code {
@@ -335,9 +335,9 @@ class Bailador::App does Bailador::Routing {
         my DateTime $start = DateTime.now;
         self.context.env = $env;
         try {
-            self!adjust-log-adapter($env),
+            self!adjust-log-adapter($env);
             my $method = $env<REQUEST_METHOD>;
-            my $uri    = uri_decode( $env<PATH_INFO> // $env<REQUEST_URI>.split('?')[0] );
+            my $uri    = uri_decode( ($env<PATH_INFO> // $env<REQUEST_URI>).Str.split('?')[0] );
             my $result = self.recurse-on-routes($method, $uri);
 
             if $.context.autorender {
