@@ -1,4 +1,5 @@
-use v6;
+use v6.c;
+
 use URI::Escape;
 
 class Bailador::Response {
